@@ -51,6 +51,8 @@ int main(int argc, char** argv)
     parser.addOption(QCommandLineOption(QStringList(QStringLiteral("l")) << QStringLiteral("list-devices"), i18n("List all devices")));
     parser.addOption(QCommandLineOption(QStringList(QStringLiteral("a")) << QStringLiteral("list-available"), i18n("List available (paired and reachable) devices")));
     parser.addOption(QCommandLineOption(QStringLiteral("id-only"), i18n("Make --list-devices or --list-available print only the devices id, to ease scripting")));
+    parser.addOption(QCommandLineOption(QStringLiteral("name-only"), i18n("Make --list-devices or --list-available print only the devices name, to ease scripting")));
+    parser.addOption(QCommandLineOption(QStringLiteral("id-name-only"), i18n("Make --list-devices or --list-available print only the devices id and name, to ease scripting")));
     parser.addOption(QCommandLineOption(QStringLiteral("refresh"), i18n("Search for devices in the network and re-establish connections")));
     parser.addOption(QCommandLineOption(QStringLiteral("pair"), i18n("Request pairing to a said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("ring"), i18n("Find the said device by ringing it.")));
@@ -67,7 +69,7 @@ int main(int argc, char** argv)
     parser.addOption(QCommandLineOption(QStringLiteral("encryption-info"), i18n("Get encryption info about said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("list-commands"), i18n("Lists remote commands and their ids")));
     parser.addOption(QCommandLineOption(QStringLiteral("execute-command"), i18n("Executes a remote command by id"), QStringLiteral("id")));
-    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("k"), QStringLiteral("send-keys")}, i18n("Sends keys to a said device")));
+    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("k"), QStringLiteral("send-keys")}, i18n("Sends keys to a said device"), QStringLiteral("key")));
     parser.addOption(QCommandLineOption(QStringLiteral("my-id"), i18n("Display this device's id and exit")));
     about.setupCommandLine(&parser);
 
@@ -81,18 +83,28 @@ int main(int argc, char** argv)
     if (parser.isSet(QStringLiteral("my-id"))) {
         QTextStream(stdout) << iface.selfId() << endl;
     } else if (parser.isSet(QStringLiteral("l")) || parser.isSet(QStringLiteral("a"))) {
-        bool paired = true, reachable = false;
+        bool reachable = false;
         if (parser.isSet(QStringLiteral("a"))) {
             reachable = true;
         } else {
             blockOnReply(iface.acquireDiscoveryMode(id));
             QThread::sleep(2);
         }
-        const QStringList devices = blockOnReply<QStringList>(iface.devices(reachable, paired));
+        const QStringList devices = blockOnReply<QStringList>(iface.devices(reachable, false));
 
+        bool displayCount = true;
         for (const QString& id : devices) {
             if (parser.isSet(QStringLiteral("id-only"))) {
                 QTextStream(stdout) << id << endl;
+                displayCount = false;
+            } else if (parser.isSet(QStringLiteral("name-only"))) {
+                DeviceDbusInterface deviceIface(id);
+                QTextStream(stdout) << deviceIface.name() << endl;
+                displayCount = false;
+            } else if (parser.isSet(QStringLiteral("id-name-only"))) {
+                DeviceDbusInterface deviceIface(id);
+                QTextStream(stdout) << id << ' ' << deviceIface.name() << endl;
+                displayCount = false;
             } else {
                 DeviceDbusInterface deviceIface(id);
                 QString statusInfo;
@@ -109,7 +121,7 @@ int main(int argc, char** argv)
                         << ": " << deviceIface.id() << ' ' << statusInfo << endl;
             }
         }
-        if (!parser.isSet(QStringLiteral("id-only"))) {
+        if (displayCount) {
             QTextStream(stdout) << i18np("1 device found", "%1 devices found", devices.size()) << endl;
         } else if (devices.isEmpty()) {
             QTextStream(stderr) << i18n("No devices found") << endl;
@@ -134,15 +146,27 @@ int main(int argc, char** argv)
             parser.showHelp(1);
         }
 
-        if(parser.isSet(QStringLiteral("share"))) {
-            QUrl url = QUrl::fromUserInput(parser.value(QStringLiteral("share")), QDir::currentPath());
-            parser.clearPositionalArguments();
-            if(!url.isEmpty() && !device.isEmpty()) {
+        if (parser.isSet(QStringLiteral("share"))) {
+            QList<QUrl> urls;
+            QUrl url = QUrl::fromUserInput(parser.value(QStringLiteral("share")));
+            urls.append(url);
+
+            //In case there are more arguments, check if they are files and then send them
+            for (const QString& file : parser.positionalArguments()) {
+                QUrl url = QUrl::fromUserInput(file, QDir::currentPath());
+                if (!url.isLocalFile()) {
+                    QTextStream(stderr) << i18n("Can't find the file: %1", url.toString()) << endl;
+                    return 1;
+                } else {
+                    urls.append(url);
+                }
+            }
+
+            for (const QUrl& url : urls) {
                 QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), "/modules/kdeconnect/devices/"+device+"/share", QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareUrl"));
                 msg.setArguments(QVariantList() << url.toString());
                 blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
-            } else {
-                QTextStream(stderr) << (i18n("Couldn't share %1", url.toString())) << endl;
+                QTextStream(stdout) << i18n("Sent %1", url.toString()) << endl;
             }
         } else if(parser.isSet(QStringLiteral("pair"))) {
             DeviceDbusInterface dev(device);
