@@ -82,7 +82,7 @@ QString LanDeviceLink::name()
     return QStringLiteral("LanLink"); // Should be same in both android and kde version
 }
 
-bool LanDeviceLink::sendPackage(NetworkPackage& np)
+bool LanDeviceLink::sendPacket(NetworkPacket& np)
 {
     if (np.hasPayload()) {
         np.setPayloadTransferInfo(sendPayload(np)->transferInfo());
@@ -90,13 +90,13 @@ bool LanDeviceLink::sendPackage(NetworkPackage& np)
 
     int written = m_socketLineReader->write(np.serialize());
 
-    //Actually we can't detect if a package is received or not. We keep TCP
+    //Actually we can't detect if a packet is received or not. We keep TCP
     //"ESTABLISHED" connections that look legit (return true when we use them),
     //but that are actually broken (until keepalive detects that they are down).
     return (written != -1);
 }
 
-UploadJob* LanDeviceLink::sendPayload(const NetworkPackage& np)
+UploadJob* LanDeviceLink::sendPayload(const NetworkPacket& np)
 {
     UploadJob* job = new UploadJob(np.payload(), deviceId());
     job->start();
@@ -107,30 +107,30 @@ void LanDeviceLink::dataReceived()
 {
     if (m_socketLineReader->bytesAvailable() == 0) return;
 
-    const QByteArray serializedPackage = m_socketLineReader->readLine();
-    NetworkPackage package(QString::null);
-    NetworkPackage::unserialize(serializedPackage, &package);
+    const QByteArray serializedPacket = m_socketLineReader->readLine();
+    NetworkPacket packet(QString{});
+    NetworkPacket::unserialize(serializedPacket, &packet);
 
-    //qCDebug(KDECONNECT_CORE) << "LanDeviceLink dataReceived" << serializedPackage;
+    //qCDebug(KDECONNECT_CORE) << "LanDeviceLink dataReceived" << serializedPacket;
 
-    if (package.type() == PACKAGE_TYPE_PAIR) {
+    if (packet.type() == PACKET_TYPE_PAIR) {
         //TODO: Handle pair/unpair requests and forward them (to the pairing handler?)
-        qobject_cast<LanLinkProvider*>(provider())->incomingPairPackage(this, package);
+        qobject_cast<LanLinkProvider*>(provider())->incomingPairPacket(this, packet);
         return;
     }
 
-    if (package.hasPayloadTransferInfo()) {
+    if (packet.hasPayloadTransferInfo()) {
         //qCDebug(KDECONNECT_CORE) << "HasPayloadTransferInfo";
-        QVariantMap transferInfo = package.payloadTransferInfo();
+        QVariantMap transferInfo = packet.payloadTransferInfo();
         //FIXME: The next two lines shouldn't be needed! Why are they here?
         transferInfo.insert(QStringLiteral("useSsl"), true);
         transferInfo.insert(QStringLiteral("deviceId"), deviceId());
         DownloadJob* job = new DownloadJob(m_socketLineReader->peerAddress(), transferInfo);
         job->start();
-        package.setPayload(job->getPayload(), package.payloadSize());
+        packet.setPayload(job->getPayload(), packet.payloadSize());
     }
 
-    Q_EMIT receivedPackage(package);
+    Q_EMIT receivedPacket(packet);
 
     if (m_socketLineReader->bytesAvailable() > 0) {
         QMetaObject::invokeMethod(this, "dataReceived", Qt::QueuedConnection);
