@@ -38,7 +38,7 @@ static QString createId() { return QCoreApplication::instance()->applicationName
 
 Q_GLOBAL_STATIC_WITH_ARGS(QString, s_keyId, (createId()));
 
-DevicesModel::DevicesModel(QObject *parent)
+DevicesModel::DevicesModel(QObject* parent)
     : QAbstractListModel(parent)
     , m_dbusInterface(new DaemonDbusInterface(this))
     , m_displayFilter(StatusFilterFlag::NoFilter)
@@ -137,7 +137,7 @@ void DevicesModel::deviceUpdated(const QString& id, bool isVisible)
         qCDebug(KDECONNECT_INTERFACES) << "Adding missing or previously removed device" << id;
         deviceAdded(id);
     } else {
-        DeviceDbusInterface *dev = getDevice(row);
+        DeviceDbusInterface* dev = getDevice(row);
         if (! passesFilter(dev)) {
             beginRemoveRows(QModelIndex(), row, row);
             delete m_deviceList.takeAt(row);
@@ -180,7 +180,7 @@ void DevicesModel::refreshDeviceList()
     bool onlyReachable = (m_displayFilter & StatusFilterFlag::Reachable);
 
     QDBusPendingReply<QStringList> pendingDeviceIds = m_dbusInterface->devices(onlyReachable, onlyPaired);
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pendingDeviceIds, this);
+    QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(pendingDeviceIds, this);
 
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished,
                      this, &DevicesModel::receivedDeviceList);
@@ -203,7 +203,7 @@ void DevicesModel::receivedDeviceList(QDBusPendingCallWatcher* watcher)
         return;
 
     beginInsertRows(QModelIndex(), 0, deviceIds.count()-1);
-    Q_FOREACH(const QString& id, deviceIds) {
+    for (const QString& id : deviceIds) {
         appendDevice(new DeviceDbusInterface(id, this));
     }
     endInsertRows();
@@ -251,6 +251,8 @@ QVariant DevicesModel::data(const QModelIndex& index, int role) const
 
     //This function gets called lots of times, producing lots of dbus calls. Add a cache?
     switch (role) {
+        case Qt::SizeHintRole:
+            return QSize(0, 32);
         case IconModelRole: {
             QString icon = data(index, IconNameRole).toString();
             return QIcon::fromTheme(icon);
