@@ -37,7 +37,7 @@ class DBusAsyncResponse : public QObject
     
 public:
     explicit DBusAsyncResponse(QObject* parent = nullptr);
-    virtual ~DBusAsyncResponse() {}; 
+    ~DBusAsyncResponse() override = default;
 
     Q_INVOKABLE void setPendingCall(QVariant e);
     
@@ -45,8 +45,8 @@ public:
     bool autodelete() const {return m_autodelete;}
     
 Q_SIGNALS:
-    void success(QVariant result);
-    void error(QString message);
+    void success(const QVariant& result);
+    void error(const QString& message);
     
 private Q_SLOTS:
     void onCallFinished(QDBusPendingCallWatcher* watcher);
