@@ -31,8 +31,9 @@
 
 #include <core/filetransferjob.h>
 
+QMap<QString, FileTransferJob*> Notification::s_downloadsInProgress;
 
-Notification::Notification(const NetworkPackage& np, QObject* parent)
+Notification::Notification(const NetworkPacket& np, QObject* parent)
     : QObject(parent)
 {
     //Make a own directory for each user so noone can see each others icons
@@ -46,11 +47,10 @@ Notification::Notification(const NetworkPackage& np, QObject* parent)
     m_imagesDir = QDir::temp().absoluteFilePath(QStringLiteral("kdeconnect_") + username);
     m_imagesDir.mkpath(m_imagesDir.absolutePath());
     QFile(m_imagesDir.absolutePath()).setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ExeOwner);
-    m_closed = false;
     m_ready = false;
 
-    parseNetworkPackage(np);
-    createKNotification(false, np);
+    parseNetworkPacket(np);
+    createKNotification(np);
 }
 
 Notification::~Notification()
@@ -69,20 +69,19 @@ void Notification::show()
     m_ready = true;
     Q_EMIT ready();
     if (!m_silent) {
-        m_closed = false;
         m_notification->sendEvent();
     }
 }
 
-void Notification::update(const NetworkPackage& np)
+void Notification::update(const NetworkPacket& np)
 {
-    parseNetworkPackage(np);
-    createKNotification(!m_closed, np);
+    parseNetworkPacket(np);
+    createKNotification(np);
 }
 
-KNotification* Notification::createKNotification(bool update, const NetworkPackage& np)
+KNotification* Notification::createKNotification(const NetworkPacket& np)
 {
-    if (!update) {
+    if (!m_notification) {
         m_notification = new KNotification(QStringLiteral("notification"), KNotification::CloseOnTimeout, this);
         m_notification->setComponentName(QStringLiteral("kdeconnect"));
     }
@@ -111,43 +110,44 @@ KNotification* Notification::createKNotification(bool update, const NetworkPacka
         applyNoIcon();
         show();
     } else {
-
         m_iconPath = m_imagesDir.absoluteFilePath(m_payloadHash);
-
-        if (!QFile::exists(m_iconPath)) {
-            loadIcon(np);
-        } else {
-            applyIcon();
-            show();
-        }
+        loadIcon(np);
     }
 
     if (!m_requestReplyId.isEmpty()) {
         m_notification->setActions(QStringList(i18n("Reply")));
-        connect(m_notification, &KNotification::action1Activated, this, &Notification::reply);
+        connect(m_notification, &KNotification::action1Activated, this, &Notification::reply, Qt::UniqueConnection);
     }
 
-    connect(m_notification, &KNotification::closed, this, &Notification::closed);
-
     return m_notification;
 }
 
-void Notification::loadIcon(const NetworkPackage& np)
+void Notification::loadIcon(const NetworkPacket& np)
 {
     m_ready = false;
-    FileTransferJob* job = np.createPayloadTransferJob(QUrl::fromLocalFile(m_iconPath));
-    job->start();
 
-    connect(job, &FileTransferJob::result, this, [this, job]{
-
-        if (job->error()) {
-            qCDebug(KDECONNECT_PLUGIN_NOTIFICATION) << "Error in FileTransferJob: " << job->errorString();
-            applyNoIcon();
-        } else {
-            applyIcon();
-        }
+    if (QFileInfo::exists(m_iconPath)) {
+        applyIcon();
         show();
-    });
+    } else {
+        FileTransferJob* fileTransferJob = s_downloadsInProgress.value(m_iconPath);
+        if (!fileTransferJob) {
+            fileTransferJob = np.createPayloadTransferJob(QUrl::fromLocalFile(m_iconPath));
+            fileTransferJob->start();
+            s_downloadsInProgress[m_iconPath] = fileTransferJob;
+        }
+
+        connect(fileTransferJob, &FileTransferJob::result, this, [this, fileTransferJob]{
+            s_downloadsInProgress.remove(m_iconPath);
+            if (fileTransferJob->error()) {
+                qCDebug(KDECONNECT_PLUGIN_NOTIFICATION) << "Error in FileTransferJob: " << fileTransferJob->errorString();
+                applyNoIcon();
+            } else {
+                applyIcon();
+            }
+            show();
+        });
+    }
 }
 
 void Notification::applyIcon()
@@ -167,12 +167,7 @@ void Notification::reply()
     Q_EMIT replyRequested();
 }
 
-void Notification::closed()
-{
-    m_closed = true;
-}
-
-void Notification::parseNetworkPackage(const NetworkPackage& np)
+void Notification::parseNetworkPacket(const NetworkPacket& np)
 {
     m_internalId = np.get<QString>(QStringLiteral("id"));
     m_appName = np.get<QString>(QStringLiteral("appName"));
