@@ -25,8 +25,9 @@
 #include <QString>
 #include <KNotification>
 #include <QDir>
+#include <QPointer>
 
-#include <core/networkpackage.h>
+#include <core/networkpacket.h>
 
 class Notification
     : public QObject
@@ -45,7 +46,7 @@ class Notification
     Q_PROPERTY(QString replyId READ replyId)
 
 public:
-    Notification(const NetworkPackage& np, QObject* parent);
+    Notification(const NetworkPacket& np, QObject* parent);
     ~Notification() override;
 
     QString internalId() const { return m_internalId; }
@@ -59,19 +60,18 @@ public:
     bool hasIcon() const { return m_hasIcon; }
     void show();
     bool silent() const { return m_silent; }
-    void update(const NetworkPackage& np);
+    void update(const NetworkPacket& np);
     bool isReady() const { return m_ready; }
-    KNotification* createKNotification(bool update, const NetworkPackage& np);
+    KNotification* createKNotification(const NetworkPacket& np);
 
 public Q_SLOTS:
     Q_SCRIPTABLE void dismiss();
     Q_SCRIPTABLE void reply();
-    void closed();
 
     Q_SIGNALS:
     void dismissRequested(const QString& m_internalId);
     void replyRequested();
-    void ready();
+    Q_SCRIPTABLE void ready();
 
 private:
     QString m_internalId;
@@ -83,17 +83,18 @@ private:
     QString m_requestReplyId;
     bool m_dismissable;
     bool m_hasIcon;
-    KNotification* m_notification;
+    QPointer<KNotification> m_notification;
     QDir m_imagesDir;
     bool m_silent;
-    bool m_closed;
     QString m_payloadHash;
     bool m_ready;
 
-    void parseNetworkPackage(const NetworkPackage& np);
-    void loadIcon(const NetworkPackage& np);
+    void parseNetworkPacket(const NetworkPacket& np);
+    void loadIcon(const NetworkPacket& np);
     void applyIcon();
     void applyNoIcon();
+
+    static QMap<QString, FileTransferJob*> s_downloadsInProgress;
 };
 
 #endif
