@@ -56,7 +56,14 @@ QStringList NotificationsDbusInterface::activeNotifications()
     return m_notifications.keys();
 }
 
-void NotificationsDbusInterface::processPackage(const NetworkPackage& np)
+void NotificationsDbusInterface::notificationReady()
+{
+    Notification* noti = static_cast<Notification*>(sender());
+    disconnect(noti, &Notification::ready, this, &NotificationsDbusInterface::notificationReady);
+    addNotification(noti);
+}
+
+void NotificationsDbusInterface::processPacket(const NetworkPacket& np)
 {
     if (np.get<bool>(QStringLiteral("isCancel"))) {
         QString id = np.get<QString>(QStringLiteral("id"));
@@ -64,46 +71,25 @@ void NotificationsDbusInterface::processPackage(const NetworkPackage& np)
         if (id.startsWith(QLatin1String("org.kde.kdeconnect_tp::")))
             id = id.mid(id.indexOf(QLatin1String("::")) + 2);
         removeNotification(id);
-    } else if (np.get<bool>(QStringLiteral("isRequest"))) {
-        for (const auto& n : qAsConst(m_notifications)) {
-            NetworkPackage np(PACKAGE_TYPE_NOTIFICATION_REQUEST, {
-                {"id", n->internalId()},
-                {"appName", n->appName()},
-                {"ticker", n->ticker()},
-                {"isClearable", n->dismissable()},
-                {"requestAnswer", true}
-            });
-            m_plugin->sendPackage(np);
-        }
-    } else if(np.get<bool>(QStringLiteral("requestAnswer"), false)) {
+        return;
+    }
 
-    } else {
-        QString id = np.get<QString>(QStringLiteral("id"));
+    QString id = np.get<QString>(QStringLiteral("id"));
 
-        if (!m_internalIdToPublicId.contains(id)) {
-            Notification* noti = new Notification(np, this);
+    Notification* noti = nullptr;
 
-            if (noti->isReady()) {
-                addNotification(noti);
-            } else {
-                connect(noti, &Notification::ready, this, [this, noti]{
-                    addNotification(noti);
-                });
-            }
+    if (!m_internalIdToPublicId.contains(id)) {
+        noti = new Notification(np, this);
+
+        if (noti->isReady()) {
+            addNotification(noti);
         } else {
-            QString pubId = m_internalIdToPublicId[id];
-            Notification* noti = m_notifications[pubId];
-            noti->update(np);
-
-            if (noti->isReady()) {
-                Q_EMIT notificationUpdated(pubId);
-            } else {
-                connect(noti, &Notification::ready, this, [this, pubId]{
-                    Q_EMIT notificationUpdated(pubId);
-                });
-            }
+            connect(noti, &Notification::ready, this, &NotificationsDbusInterface::notificationReady);
         }
-
+    } else {
+        QString pubId = m_internalIdToPublicId.value(id);
+        noti = m_notifications.value(pubId);
+        noti->update(np);
     }
 }
 
@@ -158,9 +144,9 @@ void NotificationsDbusInterface::removeNotification(const QString& internalId)
 
 void NotificationsDbusInterface::dismissRequested(const QString& internalId)
 {
-    NetworkPackage np(PACKAGE_TYPE_NOTIFICATION_REQUEST);
+    NetworkPacket np(PACKET_TYPE_NOTIFICATION_REQUEST);
     np.set<QString>(QStringLiteral("cancel"), internalId);
-    m_plugin->sendPackage(np);
+    m_plugin->sendPacket(np);
 
     //Workaround: we erase notifications without waiting a repsonse from the
     //phone because we won't receive a response if we are out of sync and this
@@ -182,10 +168,10 @@ void NotificationsDbusInterface::replyRequested(Notification* noti)
 
 void NotificationsDbusInterface::sendReply(const QString& replyId, const QString& message)
 {
-    NetworkPackage np(PACKAGE_TYPE_NOTIFICATION_REPLY);
+    NetworkPacket np(PACKET_TYPE_NOTIFICATION_REPLY);
     np.set<QString>(QStringLiteral("requestReplyId"), replyId);
     np.set<QString>(QStringLiteral("message"), message);
-    m_plugin->sendPackage(np);
+    m_plugin->sendPacket(np);
 }
 
 QString NotificationsDbusInterface::newId()
