@@ -39,7 +39,7 @@ Mounter::Mounter(SftpPlugin* sftp)
     , m_started(false)
 {
 
-    connect(m_sftp, &SftpPlugin::packetReceived, this, &Mounter::onPakcageReceived);
+    connect(m_sftp, &SftpPlugin::packetReceived, this, &Mounter::onPackageReceived);
 
     connect(&m_connectTimer, &QTimer::timeout, this, &Mounter::onMountTimeout);
 
@@ -74,7 +74,7 @@ bool Mounter::wait()
     return loop.exec();
 }
 
-void Mounter::onPakcageReceived(const NetworkPacket& np)
+void Mounter::onPackageReceived(const NetworkPacket& np)
 {
     if (np.get<bool>(QStringLiteral("stop"), false))
     {
@@ -134,7 +134,7 @@ void Mounter::onPakcageReceived(const NetworkPacket& np)
         << QStringLiteral("-o") << "IdentityFile=" + KdeConnectConfig::instance()->privateKeyPath()
         << QStringLiteral("-o") << QStringLiteral("StrictHostKeyChecking=no") //Do not ask for confirmation because it is not a known host
         << QStringLiteral("-o") << QStringLiteral("UserKnownHostsFile=/dev/null") //Prevent storing as a known host
-        << QStringLiteral("-o") << QStringLiteral("HostKeyAlgorithms=ssh-dss") //https://bugs.kde.org/show_bug.cgi?id=351725
+        << QStringLiteral("-o") << QStringLiteral("HostKeyAlgorithms=+ssh-dss") //https://bugs.kde.org/show_bug.cgi?id=351725
         << QStringLiteral("-o") << QStringLiteral("uid=") + QString::number(getuid())
         << QStringLiteral("-o") << QStringLiteral("gid=") + QString::number(getgid())
         << QStringLiteral("-o") << QStringLiteral("reconnect")
@@ -175,15 +175,23 @@ void Mounter::onError(QProcess::ProcessError error)
 {
     if (error == QProcess::FailedToStart)
     {
-        qCDebug(KDECONNECT_PLUGIN_SFTP) << "Process failed to start";
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "sshfs process failed to start";
         m_started = false;
         Q_EMIT failed(i18n("Failed to start sshfs"));
+    } else if(error == QProcess::ProcessError::Crashed) {
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "sshfs process crashed";
+        m_started = false;
+        Q_EMIT failed(i18n("sshfs process crashed"));
+    } else {
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "sshfs process error" << error;
+        m_started = false;
+        Q_EMIT failed(i18n("Unknown error in sshfs"));
     }
 }
 
 void Mounter::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    if (exitStatus == QProcess::NormalExit)
+    if (exitStatus == QProcess::NormalExit && exitCode == 0)
     {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "Process finished (exit code: " << exitCode << ")";
         Q_EMIT unmounted();
@@ -191,7 +199,7 @@ void Mounter::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
     else
     {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "Process failed (exit code:" << exitCode << ")";
-        Q_EMIT failed(i18n("Error when accessing to filesystem"));
+        Q_EMIT failed(i18n("Error when accessing filesystem. sshfs finished with exit code %0").arg(exitCode));
     }
 
     unmount(true);
